==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/sv-SE/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Tillbehör incheckat',
    'Accessory_Checkout_Notification' => 'Tillbehör utchekat',
    'Asset_Checkin_Notification' => 'Tillgång incheckat',
    'Asset_Checkout_Notification' => 'Tillgång utcheckad',
    'Confirm_Accessory_Checkin' => 'Bekräfta incheckning av tillbehör',
    'Confirm_Asset_Checkin' => 'Bekräfta incheckning av tillgång',
    'Confirm_accessory_delivery' => 'Leveransbekräftelse för tillbehör',
    'Confirm_asset_delivery' => 'Leveransbekräftelse för tillgång',
    'Confirm_consumable_delivery' => 'Leveransbekräftelse för förbrukningsvara',
    'Confirm_license_delivery' => 'Leveransbekräftelse för licens',
    'Consumable_checkout_notification' => 'Förbrukningsvara utcheckat',
    'Days' => 'Dagar',
    'Expected_Checkin_Date' => 'En tillgång som checkas ut till dig kommer att checkas in igen :date',
    'Expected_Checkin_Notification' => 'Påminnelse: :name sluttiden för incheckning närmar sig',
    'Expected_Checkin_Report' => 'Förväntad incheckningsrapport för tillgång',
    'Expiring_Assets_Report' => 'Rapport över tillgångar med förfallodatum.',
    'Expiring_Licenses_Report' => 'Rapport över licenser med förfallodatum.',
    'Item_Request_Canceled' => 'Objektförfrågan avbruten',
    'Item_Requested' => 'Objekt begärt',
    'License_Checkin_Notification' => 'Licens incheckad',
    'License_Checkout_Notification' => 'Licens utcheckad',
    'license_for'   => 'Licens för',
    'Low_Inventory_Report' => 'Meddelande om lågt lagersaldo',
    'a_user_canceled' => 'En användare har avbrutit en objektbegäran på webbplatsen',
    'a_user_requested' => 'En användare har efterfrågat ett objekt på webbplatsen',
    'acceptance_asset_accepted' => 'En användare har accepterat ett objekt',
    'acceptance_asset_declined' => 'En användare har avböjt ett objekt',
    'accessory_name' => 'Tillbehörsnamn',
    'additional_notes' => 'Ytterligare anmärkningar',
    'admin_has_created' => 'En administratör har skapat ett konto för dig på :web.',
    'asset' => 'Tillgång',
    'asset_name' => 'Företagsnamn',
    'asset_requested' => 'Tillgång begärd',
    'asset_tag' => 'Tillgångstagg',
    'assets_warrantee_alert' => 'Det finns :count tillgång vars garanti löper ut under de kommande :threshold dagar.|Det finns :count tillgångar med garantier som löper ut under de kommande :threshold dagar.',
    'assigned_to' => 'Tilldelat till',
    'best_regards' => 'Vänliga hälsningar,',
    'canceled' => 'Avbruten',
    'checkin_date' => 'Incheck.dat.',
    'checkout_date' => 'Utcheck.dat.',
    'checkedout_from' => 'Utcheckad från',
    'checkedin_from'  => 'Incheckad från',
    'checked_into' => 'Incheckad till',
    'click_on_the_link_accessory' => 'Vänligen klicka på länken nedan för att bekräfta att du har mottagit tillbehöret.',
    'click_on_the_link_asset' => 'Vänligen klicka på länken nedan för att bekräfta att du har mottagit tillgången.',
    'click_to_confirm' => 'Vänligen klicka på följande länk för att bekräfta ditt :web konto:',
    'current_QTY' => 'Nuvarande antal',
    'days' => 'Dagar',
    'expecting_checkin_date' => 'Förväntat incheck.dat.',
    'expires' => 'Utgår',
    'hello' => 'Hejsan',
    'hi' => 'Hej',
    'i_have_read' => 'Jag har läst och godkänt användarvillkoren och har mottagit det här objektet.',
    'inventory_report' => 'Inventarierapport',
    'item' => 'Objekt',
    'item_checked_reminder' => 'Detta är en påminnelse om att du för närvarande har :count objekt utcheckade till dig som du inte har accepterat eller nekat. Klicka på länken nedan för att bekräfta ditt beslut.',
    'license_expiring_alert' => ':count licens löper ut inom :threshold dagar.|:count licenser löper ut inom :threshold days.',
    'link_to_update_password' => 'Vänligen klicka på följande länk för att uppdatera ditt :web lösenord:',
    'login' => 'Logga in',
    'login_first_admin' => 'Logga in på din nya Snipe-IT-installation med hjälp av inloggningsuppgifterna nedan:',
    'low_inventory_alert' => ':count artikel understiger det lägsta tillåtna lagersaldot eller är på väg att ta slut.|:count artiklar understiger det lägsta tillåtna lagersaldot eller är på väg att ta slut.',
    'min_QTY' => 'Min. antal',
    'name' => 'Namn',
    'new_item_checked' => 'Ett nytt objekt har blivit utcheckat i ditt namn, se detaljer nedan.',
    'notes' => 'Anteckningar',
    'password' => 'Lösenord',
    'password_reset' => 'Lösenordsåterställning',
    'read_the_terms' => 'Läs användarvillkoren nedan.',
    'read_the_terms_and_click' => 'Läs användarvillkoren nedan och klicka på länken nedan för att bekräfta att du läst och godkänner användarvillkoren samt har mottagit objektet.',
    'requested' => 'Begärda',
    'reset_link' => 'Länk för att återställa ditt lösenord',
    'reset_password' => 'Klicka här för att återställa ditt lösenord:',
    'rights_reserved' => 'Med ensamrätt.',
    'serial' => 'Serienummer',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Sammanfattning av Snipe-IT-integrationen',
    'supplier' => 'Leverantör',
    'tag' => 'Tagg',
    'test_email' => 'Testa e-post från Snipe-IT',
    'test_mail_text' => 'Detta är ett test från Snipe-IT Asset Management System. Om du får detta så fungerar mejlen :)',
    'the_following_item' => 'Följande objekt har blivit incheckat: ',
    'to_reset' => 'För att återställa ditt :web lösenord, fyll i det här formuläret:',
    'type' => 'Typ',
    'upcoming-audits' => 'Det finns :count tillgång som skall inventeras inom :threshold dagar.|Det finns :count tillgångar som skall inventeras inom :threshold dagar.',
    'user' => 'Användare',
    'username' => 'Användarnamn',
    'unaccepted_asset_reminder' => 'Du har oaccepterade tillgångar.',
    'welcome' => 'Välkommen :name!',
    'welcome_to' => 'Välkommen till :web!',
    'your_assets' => 'Visa dina tillgångar',
    'your_credentials' => 'Dina Snipe-IT användaruppgifter',
    'mail_sent' => 'E-post har skickats!',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/sv-SE/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Tillbehör incheckat',
    'Accessory_Checkout_Notification' => 'Accessory checked out|:count Accessories checked out',
    'Asset_Checkin_Notification' => 'Asset checked in: :tag',
    'Asset_Checkout_Notification' => 'Asset checked out: :tag',
    'Confirm_Accessory_Checkin' => 'Bekräfta incheckning av tillbehör',
    'Confirm_Asset_Checkin' => 'Bekräfta incheckning av tillgång',
    'Confirm_component_checkin' => 'Component checkin confirmation',
    'Confirm_accessory_delivery' => 'Leveransbekräftelse för tillbehör',
    'Confirm_asset_delivery' => 'Leveransbekräftelse för tillgång',
    'Confirm_consumable_delivery' => 'Leveransbekräftelse för förbrukningsvara',
    'Confirm_component_delivery' => 'Component delivery confirmation',
    'Confirm_license_delivery' => 'Leveransbekräftelse för licens',
    'Consumable_checkout_notification' => 'Förbrukningsvara utcheckat',
    'Component_checkout_notification' => 'Component checked out',
    'Component_checkin_notification' => 'Component checked in',
    'Days' => 'Dagar',
    'Expected_Checkin_Date' => 'En tillgång som checkas ut till dig kommer att checkas in igen :date',
    'Expected_Checkin_Notification' => 'Påminnelse: :name sluttiden för incheckning närmar sig',
    'Expected_Checkin_Report' => 'Förväntad incheckningsrapport för tillgång',
    'Expiring_Assets_Report' => 'Rapport över tillgångar med förfallodatum',
    'Expiring_Licenses_Report' => 'Rapport över licenser med förfallodatum',
    'Item_Request_Canceled' => 'Objektförfrågan avbruten',
    'Item_Requested' => 'Objekt begärt',
    'License_Checkin_Notification' => 'Licens incheckad',
    'License_Checkout_Notification' => 'Licens utcheckad',
    'license_for'   => 'Licens för',
    'Low_Inventory_Report' => 'Meddelande om lågt lagersaldo',
    'a_user_canceled' => 'En användare har avbrutit en objektbegäran på webbplatsen',
    'a_user_requested' => 'En användare har efterfrågat ett objekt på webbplatsen',
    'acceptance_asset_accepted_to_user' => 'You have accepted an item assigned to you by :site_name|You have accepted :qty items assigned to you by :site_name',
    'acceptance_asset_accepted' => 'En användare har accepterat ett objekt',
    'acceptance_asset_declined' => 'En användare har avböjt ett objekt',
    'send_pdf_copy' => 'Send a copy of this acceptance to my email address',
    'accessory_name' => 'Tillbehörsnamn',
    'additional_notes' => 'Ytterligare anmärkningar',
    'admin_has_created' => 'An administrator has created an account for you on the :web website. Please find your username below, and click on the link to set a password.',
    'asset' => 'Tillgång',
    'asset_name' => 'Företagsnamn',
    'asset_requested' => 'Tillgång begärd',
    'asset_tag' => 'Tillgångstagg',
    'assets_warrantee_alert' => 'There is :count asset with an expiring warranty or that are reaching their end of life in the next :threshold days.|There are :count assets with expiring warranties or that are reaching their end of life in the next :threshold days.',
    'assigned_to' => 'Tilldelat till',
    'eol' => 'EOL',
    'best_regards' => 'Vänliga hälsningar,',
    'canceled' => 'Avbruten',
    'checkin_date' => 'Incheck.dat.',
    'checkout_date' => 'Utcheck.dat.',
    'checkedout_from' => 'Utcheckad från',
    'checkedin_from'  => 'Incheckad från',
    'checked_into' => 'Incheckad till',
    'click_on_the_link_accessory' => 'Vänligen klicka på länken nedan för att bekräfta att du har mottagit tillbehöret.',
    'click_on_the_link_asset' => 'Vänligen klicka på länken nedan för att bekräfta att du har mottagit tillgången.',
    'click_to_confirm' => 'Vänligen klicka på följande länk för att bekräfta ditt :web konto:',
    'current_QTY' => 'Nuvarande antal',
    'days' => 'Dagar',
    'expecting_checkin_date' => 'Förväntat incheck.dat.',
    'expires' => 'Utgår',
    'terminates' => 'Terminates',
    'following_accepted' => 'The following was accepted',
    'following_declined' => 'The following was declined',
    'hello' => 'Hejsan',
    'hi' => 'Hej',
    'i_have_read' => 'Jag har läst och godkänt användarvillkoren och har mottagit det här objektet.',
    'initiated_accepted' => 'A checkout you initiated was accepted',
    'initiated_declined' => 'A checkout you initiated was declined',
    'inventory_report' => 'Inventarierapport',
    'item' => 'Objekt',
    'item_checked_reminder' => 'Detta är en påminnelse om att du för närvarande har :count objekt utcheckade till dig som du inte har accepterat eller nekat. Klicka på länken nedan för att bekräfta ditt beslut.',
    'license_expiring_alert' => 'There is :count license expiring or terminating in the next :threshold days.|There are :count licenses expiring or terminating in the next :threshold days.',
    'link_to_update_password' => 'Vänligen klicka på följande länk för att uppdatera ditt :web lösenord:',
    'login' => 'Logga in',
    'login_first_admin' => 'Logga in på din nya Snipe-IT-installation med hjälp av inloggningsuppgifterna nedan:',
    'low_inventory_alert' => ':count artikel understiger det lägsta tillåtna lagersaldot eller är på väg att ta slut.|:count artiklar understiger det lägsta tillåtna lagersaldot eller är på väg att ta slut.',
    'min_QTY' => 'Min. antal',
    'name' => 'Namn',
    'new_item_checked' => 'A new item has been checked out under your name, details are below.|:count new items have been checked out under your name, details are below.',
    'new_item_checked_with_acceptance' => 'A new item has been checked out under your name that requires acceptance, details are below.|:count new items have been checked out under your name that requires acceptance, details are below.',
    'new_item_checked_location' => 'A new item has been checked out to :location, details are below.|:count new items have been checked out to :location, details are below.',
    'recent_item_checked' => 'An item was recently checked out under your name that requires acceptance, details are below.',
    'notes' => 'Anteckningar',
    'password' => 'Lösenord',
    'password_reset' => 'Lösenordsåterställning',
    'read_the_terms' => 'Läs användarvillkoren nedan.',
    'read_the_terms_and_click' => 'Läs användarvillkoren nedan och klicka på länken nedan för att bekräfta att du läst och godkänner användarvillkoren samt har mottagit objektet.',
    'requested' => 'Begärda',
    'reset_link' => 'Länk för att återställa ditt lösenord',
    'reset_password' => 'Klicka här för att återställa ditt lösenord:',
    'rights_reserved' => 'Med ensamrätt.',
    'serial' => 'Serienummer',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Sammanfattning av Snipe-IT-integrationen',
    'supplier' => 'Leverantör',
    'tag' => 'Tagg',
    'test_email' => 'Testa e-post från Snipe-IT',
    'test_mail_text' => 'Detta är ett test från Snipe-IT Asset Management System. Om du får detta så fungerar mejlen :)',
    'the_following_item' => 'Följande objekt har blivit incheckat: ',
    'to_reset' => 'För att återställa ditt :web lösenord, fyll i det här formuläret:',
    'type' => 'Typ',
    'upcoming-audits' => 'Det finns :count tillgång som skall inventeras inom :threshold dagar.|Det finns :count tillgångar som skall inventeras inom :threshold dagar.',
    'user' => 'Användare',
    'username' => 'Användarnamn',
    'unaccepted_asset_reminder' => 'Reminder: You have Unaccepted Assets.',
    'welcome' => 'Välkommen :name!',
    'welcome_to' => 'Välkommen till :web!',
    'your_assets' => 'Visa dina tillgångar',
    'your_credentials' => 'Dina Snipe-IT användaruppgifter',
    'mail_sent' => 'E-post har skickats!',
];
